@@ -8,13 +8,17 @@
 #' @param b Numeric; parameter of survival equation
 #' @param agemin Integer; age of newest vehicles for that category
 #' @param agemax Integer; age of oldest vehicles for that category
-#' @param k Integer; multiplication factor. If its length is > 1, it must match the length of x
+#' @param k Numeric; multiplication factor. If its length is > 1, it must match the length of x
 #' @param bystreet Logical; when TRUE it is expecting that 'a' and 'b' are numeric vectors with length equal to x
 #' @param net SpatialLinesDataFrame or Spatial Feature of "LINESTRING"
-#' @param message Logical;  message with average age and total numer of vehicles
+#' @param verbose Logical;  message with average age and total numer of vehicles
+#' @param namerows Any vector to be change row.names. For instance, name of
+#' regions or streets.
 #' @return dataframe of age distrubution of vehicles
 #' @importFrom sf st_sf st_as_sf
 #' @export
+#' @note It consists in a Gompertz equation with default parameters from
+#' 1 national emissions inventory for green housegases in Brazil, MCT 2006
 #' @examples {
 #' data(net)
 #' PC_E25_1400 <- age_ldv(x = net$ldv, name = "PC_E25_1400")
@@ -31,7 +35,11 @@ age_ldv <- function (x,
                      k = 1,
                      bystreet = F,
                      net,
-                     message = TRUE){
+                     verbose = FALSE,
+                     namerows){
+  #check agemax
+  if(agemax < 1) stop("Agemax should be bigger than 1")
+
   if (missing(x) | is.null(x)) {
     stop (print("Missing vehicles"))
   } else if (bystreet == T){
@@ -51,12 +59,12 @@ age_ldv <- function (x,
     for (i in seq_along(x)) {
       df[i,] <- d[[i]]
     }
-    if (agemin > 1) {
-      df <- cbind(as.data.frame(matrix(0,ncol=agemin-1, nrow=length(x))),
-                  df)
-    } else {
-      df <- df
-    }
+
+    df <- as.data.frame(cbind(as.data.frame(matrix(0,ncol=agemin-1,
+                                                   nrow=length(x))),
+                              df))
+
+    names(df) <- paste(name,seq(1,agemax),sep="_")
 
     if(length(k) > 1){
       df <- vein::matvect(df = df, x = k)
@@ -65,8 +73,7 @@ age_ldv <- function (x,
     }
 
 
-    if(message){
-    names(df) <- paste(name,seq(1,agemax),sep="_")
+    if(verbose){
     message(paste("Average age of",name, "is",
                   round(sum(seq(1,agemax)*base::colSums(df, na.rm = T)/sum(df, na.rm = T)), 2),
                   sep=" "))
@@ -77,6 +84,10 @@ age_ldv <- function (x,
     )
     cat("\n")
     }
+    if(!missing(namerows)) {
+      if(length(namerows) != nrow(df)) stop("length of namerows must be the length of number of rows of veh")
+      row.names(df) <- namerows
+    }
     if(!missing(net)){
       netsf <- sf::st_as_sf(net)
       dfsf <- sf::st_sf(Vehicles(df), geometry = netsf$geometry)
@@ -92,10 +103,12 @@ age_ldv <- function (x,
     d[length(d)+1] <- d[length(d)]
     d <- d + (1 - sum(d))/length(d)
     df <- as.data.frame(as.matrix(x) %*%matrix(d,ncol=length(anos), nrow=1))
-    if (agemin > 1) {
-      df <- cbind(as.data.frame(matrix(0,ncol=agemin-1, nrow=length(x))),
-                  df)
-    } else {df <- df}
+
+    df <- as.data.frame(cbind(as.data.frame(matrix(0,ncol=agemin-1,
+                                                   nrow=length(x))),
+                              df))
+
+    names(df) <- paste(name,seq(1,agemax),sep="_")
 
     if(length(k) > 1){
       df <- vein::matvect(df = df, x = k)
@@ -103,8 +116,7 @@ age_ldv <- function (x,
       df <- df*k
     }
 
-    if(message){
-    names(df) <- paste(name,seq(1,agemax),sep="_")
+    if(verbose){
     message(paste("Average age of",name, "is",
                   round(sum(seq(1,agemax)*base::colSums(df, na.rm = T)/sum(df, na.rm = T)), 2),
                   sep=" "))
@@ -115,6 +127,10 @@ age_ldv <- function (x,
     )
     cat("\n")
     }
+    if(!missing(namerows)) {
+      if(length(namerows) != nrow(df)) stop("length of namerows must be the length of number of rows of veh")
+      row.names(df) <- namerows
+    }
     if(!missing(net)){
       netsf <- sf::st_as_sf(net)
       dfsf <- sf::st_sf(Vehicles(df), geometry = netsf$geometry)
