@@ -16,6 +16,6 @@ test_that("ef_ldv_speed works", {
       7.916123e+01 + 2.66e-06,
       0.000000e+00,
       2.519344e+02 + 2.77e-05,
-      3.320000e-05,
+      3.320000e-05 + 0.000561,
       1.583225e-03))
 })
